==> vrt_lss_fieldservice-3.6.163073.tar.gz: vrt_lss_fieldservice-3.6.163073/vrt_lss_fieldservice/schemes/predict_result_schema.py <==
PREDICT_RESULT_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "tracedata": {
            "additionalProperties": false,
            "properties": {
                "code": {
                    "maxLength": 256,
                    "minLength": 3,
                    "type": "string"
                }
            },
            "required": [
                "code"
            ],
            "type": "object"
        },
        "windows": {
            "items": {
                "additionalProperties": false,
                "properties": {
                    "cost": {
                        "format": "double",
                        "minimum": 0,
                        "type": "number"
                    },
                    "time_window": {
                        "additionalProperties": false,
                        "properties": {
                            "from": {
                                "format": "date-time",
                                "type": "string"
                            },
                            "to": {
                                "format": "date-time",
                                "type": "string"
                            }
                        },
                        "required": [
                            "from",
                            "to"
                        ],
                        "type": "object"
                    }
                },
                "required": [
                    "time_window",
                    "cost"
                ],
                "type": "object"
            },
            "type": "array"
        }
    },
    "type": "object"
}'''

==> vrt_lss_fieldservice-3.8.171175.tar.gz: vrt_lss_fieldservice-3.8.171175/vrt_lss_fieldservice/schemes/predict_result_schema.py <==
PREDICT_RESULT_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "tracedata": {
            "additionalProperties": false,
            "properties": {
                "client": {
                    "maxLength": 256,
                    "minLength": 2,
                    "type": "string"
                },
                "code": {
                    "maxLength": 256,
                    "minLength": 3,
                    "type": "string"
                },
                "method": {
                    "enum": [
                        "PLAN",
                        "CONVERT",
                        "ANALYTICS",
                        "PREDICT",
                        "ACTUALIZE",
                        "VALIDATE",
                        "ROUTE",
                        "MATRIX",
                        "CLUSTER"
                    ],
                    "type": "string"
                },
                "server": {
                    "maxLength": 256,
                    "minLength": 2,
                    "type": "string"
                },
                "service": {
                    "enum": [
                        "LASTMILE",
                        "DELIVERY",
                        "FIELDSERVICE",
                        "MERCHANDISER",
                        "ROUTING",
                        "CLUSTERING",
                        "ACCOUNT",
                        "STOCK",
                        "ADMIN"
                    ],
                    "type": "string"
                },
                "time": {
                    "format": "date-time",
                    "type": "string"
                }
            },
            "required": [
                "code"
            ],
            "type": "object"
        },
        "windows": {
            "items": {
                "additionalProperties": false,
                "properties": {
                    "cost": {
                        "format": "double",
                        "minimum": 0,
                        "type": "number"
                    },
                    "time_window": {
                        "additionalProperties": false,
                        "properties": {
                            "from": {
                                "format": "date-time",
                                "type": "string"
                            },
                            "to": {
                                "format": "date-time",
                                "type": "string"
                            }
                        },
                        "required": [
                            "from",
                            "to"
                        ],
                        "type": "object"
                    }
                },
                "required": [
                    "time_window",
                    "cost"
                ],
                "type": "object"
            },
            "type": "array"
        }
    },
    "type": "object"
}'''
